==> haskell-missingh-1.4.1.0-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.1.0
id: MissingH-1.4.1.0-IYLwDgSifubFp3Jkq7t5J8
key: MissingH-1.4.1.0-IYLwDgSifubFp3Jkq7t5J8
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
abi: 517836a777bcdc696672910e5aaa9d0e
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
import-dirs: /usr/lib/ghc-8.6.4/site-local/MissingH-1.4.1.0
library-dirs: /usr/lib/ghc-8.6.4/site-local/MissingH-1.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/MissingH-1.4.1.0
hs-libraries: HSMissingH-1.4.1.0-IYLwDgSifubFp3Jkq7t5J8
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj array-0.5.3.0 base-4.12.0.0
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    hslogger-1.2.12-F0MffX4tOREI9yTBXZilsJ mtl-2.2.2
    network-2.8.0.0-79Coriq35AYDs1MobOTL51
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-compat-0.95.1-KWHpBxMrkPb1MX7UzruPB9 time-1.8.0.2
    unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.4.1.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: MissingH
version: 1.4.1.0
id: MissingH-1.4.1.0-4OCFnuIfeUX3uAa4nUBTgF
key: MissingH-1.4.1.0-4OCFnuIfeUX3uAa4nUBTgF
license: BSD-3-Clause
copyright: Copyright (c) 2004-2018 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Beta
homepage: http://software.complete.org/missingh
synopsis: Large utility library
description:
    MissingH is a library of all sorts of utility functions for
    Haskell programmers.  It is written in pure Haskell and thus should
    be extremely portable and easy to use.
category: Unclassified
abi: 37509de628f73290735ccde027428c35
exposed: True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/MissingH-1.4.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/MissingH-1.4.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/MissingH-1.4.1.0
hs-libraries: HSMissingH-1.4.1.0-4OCFnuIfeUX3uAa4nUBTgF
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj array-0.5.3.0 base-4.12.0.0
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    hslogger-1.2.12-Gq2to3uWnQ8FJbgSSZMEla mtl-2.2.2
    network-2.8.0.0-g7zeLS1MQKFu6rNI1xGwt
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    old-time-1.1.0.3-HsoRJMkCHriE79r63Cxfu4 parsec-3.1.13.0
    process-1.6.5.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    regex-compat-0.95.1-KWHpBxMrkPb1MX7UzruPB9 time-1.8.0.2
    unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html: /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
